==> mx-packageinstaller-pkglist_19.07.06.tar.xz: mx-packageinstaller-pkglist/simplescreenrecorder.pm <==
<?xml version="1.0"?>
<app>


<category>
Screencast
</category>

<name>
SimpleScreenRecorder
</name>

<description>
   <am>a Qt-based screencast recorder</am>
   <ar>a Qt-based screencast recorder</ar>
   <bg>a Qt-based screencast recorder</bg>
   <ca>Enregistrador de pantalla basat en QT</ca>
   <cs>a Qt-based screencast recorder</cs>
   <da>en Qt-baseret screencast-optager</da>
   <de>Ein Qt-basierter Bildschirm-Rekorder</de>
   <el>μια καταγραφική εκπομπής με βάση το Qt</el>
   <en>a Qt-based screencast recorder</en>
   <es>grabador de pantalla basado en Qt</es>
   <et>a Qt-based screencast recorder</et>
   <eu>a Qt-based screencast recorder</eu>
   <fa>a Qt-based screencast recorder</fa>
   <fi>a Qt-based screencast recorder</fi>
   <fr>Outil de capture vidéo basé sur Qt</fr>
   <he_IL>a Qt-based screencast recorder</he_IL>
   <hi>a Qt-based screencast recorder</hi>
   <hr>a Qt-based screencast recorder</hr>
   <hu>a Qt-based screencast recorder</hu>
   <id>a Qt-based screencast recorder</id>
   <is>a Qt-based screencast recorder</is>
   <it>registratore dello schermo basato su librerie Qt</it>
   <ja_JP>a Qt-based screencast recorder</ja_JP>
   <ja>a Qt-based screencast recorder</ja>
   <kk>a Qt-based screencast recorder</kk>
   <ko>a Qt-based screencast recorder</ko>
   <lt>a Qt-based screencast recorder</lt>
   <mk>a Qt-based screencast recorder</mk>
   <nb>a Qt-based screencast recorder</nb>
   <nl>a Qt-gebaseerde screencast recorder</nl>
   <pl>rejestrator ekranu oparty na QT</pl>
   <pt_BR>a Qt-based screencast recorder</pt_BR>
   <pt>a Qt-based screencast recorder</pt>
   <ro>a Qt-based screencast recorder</ro>
   <ru>Запись скринкастов</ru>
   <sk>a Qt-based screencast recorder</sk>
   <sl>a Qt-based screencast recorder</sl>
   <sq>a Qt-based screencast recorder</sq>
   <sr>a Qt-based screencast recorder</sr>
   <sv>en Qt-baserad skärmbildsinspelare</sv>
   <tr>a Qt-based screencast recorder</tr>
   <uk>a Qt-based screencast recorder</uk>
   <zh_CN>a Qt-based screencast recorder</zh_CN>
   <zh_TW>a Qt-based screencast recorder</zh_TW>
</description>

<installable>
all
</installable>

<screenshot>https://screenshots.debian.net/screenshots/000/015/303/large.png</screenshot>

<preinstall>

</preinstall>

<install_package_names>
simplescreenrecorder
</install_package_names>


<postinstall>

</postinstall>


<uninstall_package_names>
simplescreenrecorder
</uninstall_package_names>

</app>

==> mx-packageinstaller-pkglist_19.09.01.tar.xz: mx-packageinstaller-pkglist/simplescreenrecorder.pm <==
<?xml version="1.0"?>
<app>


<category>
Screencast
</category>

<name>
SimpleScreenRecorder
</name>

<description>
   <am>a Qt-based screencast recorder</am>
   <ar>a Qt-based screencast recorder</ar>
   <bg>a Qt-based screencast recorder</bg>
   <ca>Enregistrador de pantalla basat en QT</ca>
   <cs>a Qt-based screencast recorder</cs>
   <da>en Qt-baseret screencast-optager</da>
   <de>Ein Qt-basierter Bildschirm-Rekorder</de>
   <el>μια καταγραφική εκπομπής με βάση το Qt</el>
   <en>a Qt-based screencast recorder</en>
   <es>Grabador de pantalla basado en Qt</es>
   <et>a Qt-based screencast recorder</et>
   <eu>a Qt-based screencast recorder</eu>
   <fa>a Qt-based screencast recorder</fa>
   <fi>a Qt-based screencast recorder</fi>
   <fr>Outil de capture vidéo basé sur Qt</fr>
   <he_IL>a Qt-based screencast recorder</he_IL>
   <hi>a Qt-based screencast recorder</hi>
   <hr>a Qt-based screencast recorder</hr>
   <hu>a Qt-based screencast recorder</hu>
   <id>a Qt-based screencast recorder</id>
   <is>a Qt-based screencast recorder</is>
   <it>registratore dello schermo basato su librerie Qt</it>
   <ja_JP>a Qt-based screencast recorder</ja_JP>
   <ja>a Qt-based screencast recorder</ja>
   <kk>a Qt-based screencast recorder</kk>
   <ko>a Qt-based screencast recorder</ko>
   <lt>a Qt-based screencast recorder</lt>
   <mk>a Qt-based screencast recorder</mk>
   <nb>a Qt-based screencast recorder</nb>
   <nl>a Qt-gebaseerde screencast recorder</nl>
   <pl>rejestrator ekranu oparty na QT</pl>
   <pt_BR>Gravador de vídeo na tela baseado em Qt</pt_BR>
   <pt>Gravador de vídeo no ecrã baseado em Qt</pt>
   <ro>a Qt-based screencast recorder</ro>
   <ru>Запись скринкастов</ru>
   <sk>a Qt-based screencast recorder</sk>
   <sl>a Qt-based screencast recorder</sl>
   <sq>a Qt-based screencast recorder</sq>
   <sr>a Qt-based screencast recorder</sr>
   <sv>en Qt-baserad skärmbildsinspelare</sv>
   <tr>a Qt-based screencast recorder</tr>
   <uk>a Qt-based screencast recorder</uk>
   <zh_CN>a Qt-based screencast recorder</zh_CN>
   <zh_TW>a Qt-based screencast recorder</zh_TW>
</description>

<installable>
all
</installable>

<screenshot>https://screenshots.debian.net/screenshots/000/015/303/large.png</screenshot>

<preinstall>

</preinstall>

<install_package_names>
simplescreenrecorder
</install_package_names>


<postinstall>

</postinstall>


<uninstall_package_names>
simplescreenrecorder
</uninstall_package_names>

</app>
